'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-2a6e6244.js');
const index_esm_min$1 = require('./index.esm.min-5281696d.js');
const index_esm_min = require('./index.esm.min-596e4656.js');
const sdkRedux = require('@boldpenguin/sdk-redux');
const store = require('./store-fe3d3434.js');

const bpSdkQuestionGroupCss = ".bp-sdk-row{display:flex;flex-direction:row}.bp-sdk-column{display:flex;flex-direction:column}.bp-sdk-space-between{justify-content:space-between}";

let BpSdkQuestionGroup = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    /**
     * answers in group
     */
    this.answers = [];
    /**
     * Classes for styling group
     */
    this.classes = '';
    /**
     * Label id's for group
     */
    this.labelId = index_esm_min.fx(8);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group');
    customElements.whenDefined('bp-sdk-external-question-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-question-group", { answers: this.answers, classes: this.classes, label: this.label, labelId: this.labelId, questionGroup: this.questionGroup, type: this.type }));
  }
  shouldRenderLabel() {
    // Adding a check to avoid accordion groups double rendering labels, this can likely be expanded to other group types but I don't have example data to test with
    return this.label && this.type !== index_esm_min$1.O.Accordion;
  }
  renderInternal() {
    return [
      this.shouldRenderLabel() && index.h("bp-sdk-question-group-label", { labelId: this.labelId, label: this.label }),
      index.h("div", { class: this.classes }, this.renderContent()),
    ];
  }
  renderContent() {
    switch (this.type) {
      case index_esm_min$1.O.Address:
        return index.h("bp-sdk-address-group", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case index_esm_min$1.O.AccumulatePercentage:
        return index.h("bp-sdk-accumulation-question-group-container", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case index_esm_min$1.O.Vehicle:
        return index.h("bp-sdk-vehicle-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Driver:
        return index.h("bp-sdk-driver-question-pool-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Stepper:
        return index.h("bp-sdk-stepper-group-container", { questionGroup: this.questionGroup });
      case index_esm_min$1.O.Accordion:
        return index.h("bp-sdk-accordion", { questionGroup: this.questionGroup });
      default:
        return this.answers.map((answer) => (index.h("bp-sdk-dynamic-input-redux-container", { answer: answer, shouldHideLabel: index_esm_min.bL(this.label, answer), labelledBy: this.label ? this.labelId : '', id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" })));
    }
  }
};
BpSdkQuestionGroup.style = bpSdkQuestionGroupCss;

const bpSdkQuestionGroupLabelCss = "";

let BpSdkQuestionGroupLabel = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-label');
    customElements.whenDefined('bp-sdk-external-question-group-label').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return index.h("bp-sdk-external-question-group-label", { label: this.label, labelId: this.labelId });
  }
  renderInternal() {
    return (index.h("h2", { id: this.labelId, class: "bp-sdk-question-group__label" }, this.label));
  }
};
BpSdkQuestionGroupLabel.style = bpSdkQuestionGroupLabelCss;

const bpSdkVehicleQuestionPoolContainerCss = "";

let BpSdkVehicleQuestionPoolContainer = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.deletePool = index.createEvent(this, "deletePool", 7);
    this.useExternal = false;
    this.isDeleting = false;
    this.handleSubscriptions = () => {
      if (store.canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.store.mapDispatchToProps(this, { removeQuestionPool: sdkRedux.removeQuestionPool });
        this.storeUnsubscribe = store.store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: sdkRedux.getFormId(state),
        config: sdkRedux.getPartnerEngineConfig(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-question-pool-container');
    customElements.whenDefined('bp-sdk-external-vehicle-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (index.h("bp-sdk-external-vehicle-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup }));
  }
  renderInternal() {
    return (!this.isDeleting &&
      !!this.questionPoolId && (index.h("bp-sdk-vehicle-panel-container", { canDelete: true, isVehicleTrailer: index_esm_min.d9(this.questionGroup), onDeleteItem: this.handleDeleteItem, questionGroup: this.questionGroup, answers: index_esm_min.Q9(this.questionGroup), shouldShowTrailers: this.questionGroup.order >= 1 || index_esm_min.d9(this.questionGroup) })));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkVehicleQuestionPoolContainer.style = bpSdkVehicleQuestionPoolContainerCss;

exports.bp_sdk_question_group = BpSdkQuestionGroup;
exports.bp_sdk_question_group_label = BpSdkQuestionGroupLabel;
exports.bp_sdk_vehicle_question_pool_container = BpSdkVehicleQuestionPoolContainer;
