import { Component, Prop, h, State, Watch, Event } from '@stencil/core';
export class BpSdkCheckboxInput {
  constructor() {
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * is pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    this.useExternal = false;
    this.onChange = (ev) => {
      const checked = ev.target.checked;
      this.valueUpdate.emit(checked);
    };
  }
  onCodeChange(code) {
    this.updateId(code, this.answerId);
  }
  onAnswerIdChange(answerId) {
    this.updateId(this.code, answerId);
  }
  updateId(code, answerId) {
    this.id = `bp-sdk-checkbox-${code}-${answerId}-input`;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-checkbox-input');
    customElements.whenDefined('bp-sdk-external-checkbox-input').then(() => {
      this.useExternal = true;
    });
    this.onCodeChange(this.code);
    this.onAnswerIdChange(this.answerId);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-checkbox-input", { answeredBySource: this.answeredBySource, answerId: this.answerId, code: this.code, errorText: this.errorText, errors: this.errors, fieldType: this.fieldType, helpText: this.helpText, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, label: this.label, labelledBy: this.labelledBy, pristine: this.pristine, questionId: this.questionId, required: this.required, touched: this.touched, value: this.value }));
  }
  renderInternal() {
    var _a;
    return (h("div", { class: "bp-sdk-checkbox__container" },
      h("div", { class: "bp-sdk-checkbox__wrapper" },
        !this.isReadOnly && (h("input", { id: this.id, class: "bp-sdk-checkbox__input", type: "checkbox", "aria-labelledby": this.labelledBy, name: this.code, checked: !!this.value, onChange: this.onChange })),
        h("label", { htmlFor: this.id, class: {
            'bp-sdk-checkbox__label': true,
            'read-only': this.isReadOnly,
          } }, this.label),
        this.isReadOnly && this.renderReadOnlyElement(this.value ? 'Yes' : 'No')),
      this.touched && !this.pristine && ((this.errorText && !this.isCompleted) || !!((_a = this.errors) === null || _a === void 0 ? void 0 : _a.length)) && (h("bp-sdk-errors-container", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, errors: this.errors, errorText: this.errorText }))));
  }
  renderReadOnlyElement(value) {
    return h("span", { class: "read-only-value" }, value);
  }
  static get is() { return "bp-sdk-checkbox-input"; }
  static get originalStyleUrls() { return {
    "$": ["bp-sdk-checkbox-input.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-checkbox-input.css"]
  }; }
  static get properties() { return {
    "answerId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Answer id"
      },
      "attribute": "answer-id",
      "reflect": false
    },
    "questionId": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question Id"
      },
      "attribute": "question_id",
      "reflect": false
    },
    "fieldType": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Field type"
      },
      "attribute": "field_type",
      "reflect": false
    },
    "errors": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "string[]",
        "resolved": "string[]",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Checkbox errors"
      }
    },
    "errorText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Error message to display"
      },
      "attribute": "error_text",
      "reflect": false
    },
    "code": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question code"
      },
      "attribute": "code",
      "reflect": false
    },
    "value": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question value"
      },
      "attribute": "value",
      "reflect": false
    },
    "label": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Label to display"
      },
      "attribute": "label",
      "reflect": false
    },
    "labelledBy": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Labels that describe group"
      },
      "attribute": "labelled-by",
      "reflect": false
    },
    "required": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is required"
      },
      "attribute": "required",
      "reflect": false
    },
    "touched": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is touched"
      },
      "attribute": "touched",
      "reflect": false,
      "defaultValue": "false"
    },
    "pristine": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "is pristine"
      },
      "attribute": "pristine",
      "reflect": false,
      "defaultValue": "true"
    },
    "isCompleted": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Is answer in complete state"
      },
      "attribute": "is_completed",
      "reflect": false,
      "defaultValue": "false"
    },
    "isReadOnly": {
      "type": "boolean",
      "mutable": false,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "When true, the field will be readonly. It will display only the label and value as plain text."
      },
      "attribute": "is-read-only",
      "reflect": false,
      "defaultValue": "false"
    },
    "helpText": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Help text"
      },
      "attribute": "help-text",
      "reflect": false
    },
    "answeredBySource": {
      "type": "string",
      "mutable": false,
      "complexType": {
        "original": "string | undefined",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Specifically how the question was answered (ie. \"ACORD 126\")"
      },
      "attribute": "answered-by-source",
      "reflect": false
    }
  }; }
  static get states() { return {
    "id": {},
    "useExternal": {}
  }; }
  static get events() { return [{
      "method": "valueUpdate",
      "name": "valueUpdate",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      }
    }]; }
  static get watchers() { return [{
      "propName": "code",
      "methodName": "onCodeChange"
    }, {
      "propName": "answerId",
      "methodName": "onAnswerIdChange"
    }]; }
}
