import { getFormId, getPartnerEngineConfig, getQuestionSets, removeQuestionPool } from '@boldpenguin/sdk-redux';
import { Component, Element, Event, h, Prop, State, Watch } from '@stencil/core';
import { store } from '@stencil/redux';
import { canGetStore } from '../../utils/store';
export class BpSdkDriverQuestionPoolContainer {
  constructor() {
    this.questionSets = [];
    this.useExternal = false;
    this.isDeleting = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
        questionSets: getQuestionSets(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-driver-question-pool-container');
    customElements.whenDefined('bp-sdk-external-driver-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-driver-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup, questionSets: this.questionSets }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-driver-question-pool-container__container" }, !this.isDeleting && !!this.questionPoolId && (h("bp-sdk-driver-group", { group: this.questionGroup, canDelete: true, onDeleteItem: this.handleDeleteItem }))));
  }
  static get is() { return "bp-sdk-driver-question-pool-container"; }
  static get originalStyleUrls() { return {
    "$": ["./bp-sdk-driver-question-pool-container.css"]
  }; }
  static get styleUrls() { return {
    "$": ["bp-sdk-driver-question-pool-container.css"]
  }; }
  static get properties() { return {
    "questionGroup": {
      "type": "unknown",
      "mutable": false,
      "complexType": {
        "original": "IMappedQuestionGroupAnswers",
        "resolved": "IMappedQuestionGroupAnswers",
        "references": {
          "IMappedQuestionGroupAnswers": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Question Group"
      }
    },
    "applicationId": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "attribute": "application-id",
      "reflect": false
    },
    "config": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IPartnerEngineConfig",
        "resolved": "IPartnerEngineConfig",
        "references": {
          "IPartnerEngineConfig": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      }
    },
    "questionSets": {
      "type": "unknown",
      "mutable": true,
      "complexType": {
        "original": "IApplicationFormQuestionSet[]",
        "resolved": "IApplicationFormQuestionSet[]",
        "references": {
          "IApplicationFormQuestionSet": {
            "location": "import",
            "path": "@boldpenguin/sdk-types"
          }
        }
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": ""
      },
      "defaultValue": "[]"
    }
  }; }
  static get states() { return {
    "useExternal": {},
    "questionPool": {},
    "questionPoolId": {},
    "isDeleting": {}
  }; }
  static get events() { return [{
      "method": "deletePool",
      "name": "deletePool",
      "bubbles": true,
      "cancelable": true,
      "composed": true,
      "docs": {
        "tags": [],
        "text": ""
      },
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      }
    }]; }
  static get elementRef() { return "el"; }
  static get watchers() { return [{
      "propName": "questionGroup",
      "methodName": "onQuestionGroupChange"
    }]; }
}
