import { r as registerInstance, c as createEvent, h, g as getElement } from './index-b4e0290f.js';
import { d as debounce_1 } from './debounce-fb08fcae.js';
import { F as Fe, i as ix, I as a3, j as fx, D as ax, E as dx, G as f4 } from './index.esm.min-bfc5f0f4.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { getConfigOptions, areDetailedRelevanceChipsEnabled, doesUserOwnApplicationForm, userHasPermission, getUnansweredRefiltersByQuestionId, isAutocompleteEnabled } from '@boldpenguin/sdk-redux';
import { v, h as h$1, t, u } from './index.esm.min-f8b70f0b.js';
import { i as isEqual_1 } from './isEqual-080a9417.js';
import { V as VehicleVinService } from './vehicle-vin.service-a399f934.js';
import './_commonjsHelpers-5e4b1d1a.js';

const bpSdkAddItemContainerCss = "";

let BpSdkAddItemContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.addItem = createEvent(this, "addItem", 7);
    /**
     * Help text
     */
    this.helpText = '';
    /**
     * Add button text
     */
    this.text = '+';
    /**
     * Can add more state
     */
    this.canAddMore = true;
    this.useExternal = false;
    this.handleClick = () => {
      this.addItem.emit();
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-add-item-container');
    customElements.whenDefined('bp-sdk-external-add-item-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return [
      h("slot", null),
      h("bp-sdk-external-add-item-container", { helpText: this.helpText, text: this.text, canAddMore: this.canAddMore, icon: this.icon }),
    ];
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-add-item__container" }, h("slot", null), this.canAddMore && (h("div", { class: "bp-sdk-add-item__wrapper" }, h("bp-sdk-icon-container", { name: this.icon }), this.helpText && h("h4", { class: "bp-sdk-add-item__help-text" }, this.helpText), h("bp-sdk-button", { onClick: this.handleClick, text: this.text })))));
  }
};
BpSdkAddItemContainer.style = bpSdkAddItemContainerCss;

const bpSdkAutocompleteInputCss = "bp-sdk-autocomplete-input .bp-sdk-autocomplete-container{position:relative;min-width:10rem;max-width:100vw}.bp-sdk-label-content{font-size:26px;color:rgba(100, 100, 100, 0.6)}.bp-sdk-no-selection{user-select:none}.bp-sdk-visually-hidden{display:none}.bp-sdk-align-right{margin-left:auto}.bp-sdk-autocomplete__button-arrow{font-size:20px}.bp-sdk-autocomplete__input{width:100%;height:2rem;padding:0.25rem;margin-bottom:0;display:flex;justify-items:center;align-items:flex-start}.bp-sdk-autocomplete__list{background:white;border:1px solid #aaa;left:0;margin:0;max-height:15rem;min-width:10rem;overflow-y:auto;padding-left:0;position:absolute;width:calc(100% - 2px);z-index:1}.bp-sdk-no-results{position:absolute;left:0;right:-2px;font-size:1rem;background:white;border:1px solid #aaa;color:#707070;padding-left:0.2rem}.bp-sdk-autocomplete__list-item{display:block;position:relative;font-size:16px;padding-left:1rem;padding-right:1rem;cursor:pointer}";

const keyboardNavigation$1 = {
  next: ['ArrowDown'],
  previous: ['ArrowUp'],
  select: ['Enter'],
};
let BpSdkAutocompleteInput = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueUpdate = createEvent(this, "valueUpdate", 7);
    this.filterUpdate = createEvent(this, "filterUpdate", 7);
    this.removeActiveAnswer = createEvent(this, "removeActiveAnswer", 7);
    this.updateActiveAnswer = createEvent(this, "updateActiveAnswer", 7);
    /***
     * Choices to display
     */
    this.choices = [];
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Is required
     */
    this.required = false;
    /**
     * Show choices
     */
    this.showChoices = false;
    /**
     * Is touched
     */
    this.touched = false;
    /**
     * Is pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    /**
     * Disables dropdown
     */
    this.disableDropdown = false;
    /**
     * Allow text to fall through if no selected choices
     */
    this.allowFallthrough = false;
    /**
     * Should show no choices fallback if list is empty
     */
    this.showNoChoicesFallback = true;
    this._choices = [];
    this._showChoices = false;
    this.filterText = '';
    this.choiceText = '';
    this.focusedIndex = 0;
    this.useExternal = false;
    this.isFocused = false;
    this.text = '';
    this.hideChoices = () => {
      this._showChoices = false;
    };
    this.onFocus = () => {
      this.isFocused = true;
    };
    this.onBlur = () => {
      if (!this.disableDropdown) {
        this.el.querySelector('input').value = this.getText(this.choice);
      }
      this.isFocused = false;
    };
    this.debounceFilterChoices = debounce_1(this.filterChoices, 300);
    this.choiceSelected = (choice) => {
      var _a;
      this._showChoices = false;
      if (choice) {
        this.choice = choice;
        this.value = choice.id;
      }
      else if (this.allowFallthrough) {
        this.value = this.filterText;
      }
      (_a = this.el.querySelector('.bp-sdk-autocomplete__input')) === null || _a === void 0 ? void 0 : _a.focus();
      this.removeActiveAnswer.emit();
    };
    this.onKeydown = (event) => {
      const key = event.key;
      if (event.metaKey || event.altKey) {
        return;
      }
      switch (key) {
        case 'ArrowUp':
        case 'ArrowDown':
        case 'Enter':
          event.preventDefault();
          this.handleKeyEvent(key);
          break;
        case 'Tab':
        case 'Escape':
          this._showChoices = false;
          break;
        case 'Meta':
        case 'Control':
        case 'Alt':
          break;
        default:
          this.debounceFilterChoices();
          break;
      }
    };
    this.onOptionClick = (choice) => (e) => {
      e.preventDefault();
      this.choiceSelected(choice);
    };
  }
  resetState() {
    this._showChoices = false;
    this.focusedIndex = 0;
    this.isFocused = false;
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-autocomplete-input');
    customElements.whenDefined('bp-sdk-external-autocomplete-input').then(() => {
      this.useExternal = true;
    });
    this.onChoicesChange(this.choices);
    this.onChoiceIdChange(this.choiceId);
    this.onShowChoicesChange(this.showChoices);
    this.onChoiceChange(this.choice);
    this.onAriaLabelledByChange(this.labelId);
    this.onLabelledByChange(this.labelledBy);
    this.checkForSelectedChoice();
  }
  onAriaLabelledByChange(labelId) {
    this.updateLabelledBy(labelId, this.labelledBy);
  }
  onLabelledByChange(labelledBy) {
    this.updateLabelledBy(this.labelId, labelledBy);
  }
  updateLabelledBy(aria, ids) {
    const prefix = ids ? `${ids} ` : '';
    this._labelledBy = `${prefix}${aria !== null && aria !== void 0 ? aria : ''}` || undefined;
  }
  onChoicesChange(choices) {
    if (JSON.stringify(choices) !== JSON.stringify(this._choices)) {
      this._choices = choices;
    }
    this.onChoiceIdChange(this.choiceId);
  }
  onChoiceIdChange(choiceId) {
    this.choice = this._choices.find((choice) => choice.id === choiceId);
  }
  onShowChoicesChange(newValue) {
    this._showChoices = this.isFocused && newValue;
  }
  getText(choice) {
    return choice ? this.displayChoice(choice) : '';
  }
  onChoiceChange(choice) {
    this.choiceText = this.getText(choice);
  }
  onChoiceTextChange(text) {
    this.text = text;
  }
  onValueChange(newValue, oldValue) {
    this._showChoices = false;
    if (newValue !== this.choiceId && Fe(newValue, oldValue)) {
      this.valueUpdate.emit([newValue]);
    }
  }
  filterChoices() {
    const input = this.el.querySelector('input');
    this.text = this.filterText = input.value;
    this._showChoices = this.isFocused && !!this.filterText;
  }
  onFilterChange(value) {
    this._showChoices = this.isFocused;
    this.updateActiveAnswer.emit(this.answerId);
    this.filterUpdate.emit({
      id: this.questionId,
      value,
    });
  }
  checkForSelectedChoice() {
    if (this.choiceId) {
      this._choices.map((choice) => {
        if (this.choiceId === choice.id) {
          this.value = choice.id;
          this.choice = choice;
        }
      });
    }
  }
  displayChoice(choice) {
    return choice === null || choice === void 0 ? void 0 : choice.value;
  }
  handleKeyEvent(keyName) {
    const options = this.getKeyEventOptions(keyName);
    const indexToSelect = this.getIndexToSelect(keyName, options);
    this.mapKeyEventToAction(indexToSelect, options);
  }
  getKeyEventOptions(keyName) {
    const goToNext = keyboardNavigation$1.next.includes(keyName);
    const goToPrevious = keyboardNavigation$1.previous.includes(keyName);
    const isOpenOrSelectKey = keyboardNavigation$1.select.includes(keyName);
    return {
      goToNext,
      goToPrevious,
      shouldMoveIndex: this._showChoices && (goToPrevious || goToNext),
      isOpenOrSelectKey,
    };
  }
  getIndexToSelect(keyName, { goToPrevious, shouldMoveIndex, isOpenOrSelectKey }) {
    let indexToSelect;
    if (isOpenOrSelectKey && this._showChoices) {
      indexToSelect = this.focusedIndex;
    }
    else if (keyName === 'Escape') {
      this._showChoices = false;
    }
    else if (shouldMoveIndex && !this._showChoices) {
      indexToSelect = this.focusedIndex == null ? 0 : this.focusedIndex + (goToPrevious ? -1 : 1);
    }
    return indexToSelect;
  }
  mapKeyEventToAction(indexToSelect, { shouldMoveIndex, goToPrevious, goToNext, }) {
    if (typeof indexToSelect === 'number') {
      this.selectOptionByIndex(indexToSelect);
    }
    else if (shouldMoveIndex && this._showChoices) {
      this.focusOption(this.focusedIndex + (goToPrevious ? -1 : 1));
    }
    else if (goToNext || goToPrevious) {
      this.filterText = this.displayChoice(this.choice);
      this.focusOption(0);
    }
  }
  focusOption(index) {
    this._showChoices = this.isFocused;
    this.focusedIndex = this.getSelectableIndex(index);
  }
  selectOptionByIndex(index) {
    const selectableIndex = this.getSelectableIndex(index);
    this.focusedIndex = selectableIndex;
    const choice = this._choices[this.focusedIndex];
    this.choiceSelected(choice);
  }
  getSelectableIndex(index) {
    const lastIndex = this._choices.length - 1;
    const selectableIndex = index <= 0 ? 0 : index > lastIndex ? lastIndex : index;
    return selectableIndex;
  }
  handleOutsideClick() {
    this.hideChoices();
  }
  handleClick(e) {
    if (this.useExternal) {
      return;
    }
    e.stopPropagation();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-autocomplete-input", { allowFallthrough: this.allowFallthrough, answerId: this.answerId, choiceId: this.choiceId, choices: this._choices, code: this.code, disableDropdown: this.disableDropdown, errorText: this.errorText, errors: this.errors, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, required: this.required, showChoices: this.showChoices, showNoChoicesFallback: this.showNoChoicesFallback, touched: this.touched }));
  }
  renderInternal() {
    var _a;
    let input;
    if (this.isReadOnly) {
      input = this.renderReadOnlyElement(this.text);
    }
    else {
      input = [
        h("input", { id: `bp-sdk-autocomplete__${this.answerId}`, class: "bp-sdk-autocomplete__input", "aria-controls": `bp-sdk-autocomplete__${this.answerId}-listbox`, "aria-autocomplete": "list", placeholder: this.placeholder, "aria-labelledby": this._labelledBy, type: "text", value: this.text, onBlur: this.onBlur, onFocus: this.onFocus, onKeyDown: this.onKeydown }),
        this.renderOptions(),
      ];
    }
    return (h("div", { class: "bp-sdk-autocomplete__container", "aria-expanded": this._showChoices, "aria-owns": `bp-sdk-autocomplete__${this.answerId}-listbox`, "aria-haspopup": "listbox", onBlur: this.hideChoices }, h("label", { id: this.labelId, htmlFor: `bp-sdk-autocomplete__${this.answerId}`, class: "bp-sdk-label bp-sdk-autocomplete__label", innerHTML: this.label }), input, this.touched && !this.pristine && ((this.errorText && !this.isCompleted) || !!((_a = this.errors) === null || _a === void 0 ? void 0 : _a.length)) && (h("bp-sdk-errors-container", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, errors: this.errors, errorText: this.errorText }))));
  }
  renderOptions() {
    var _a;
    if (this.disableDropdown) {
      return;
    }
    else if ((_a = this._choices) === null || _a === void 0 ? void 0 : _a.length) {
      return (h("ul", { class: ix('bp-sdk-autocomplete__list', {
          'bp-sdk-visually-hidden': !this._showChoices,
        }), id: `bp-sdk-autocomplete__${this.answerId}-listbox`, role: "listbox", "aria-labelledby": this.labelId, tabindex: "-1" }, this._choices.map((choice, i) => (h("li", { onClick: this.onOptionClick(choice), "aria-labelledby": this.labelId, class: ix(`bp-sdk-autocomplete__list-item bp-sdk-autocomplete__item-${choice.id}`, {
          'bp-sdk-autocomplete__list-item--selected': this.choiceId === choice.id,
        }), role: "option", "aria-selected": (this.focusedIndex == i).toString(), tabindex: "1" }, h("span", { class: `bp-sdk-autocomplete__list-item-text bp-sdk-autocomplete__list-item-text-${choice.id}` }, this.displayChoice(choice)))))));
    }
    else if (this.showNoChoicesFallback) {
      return (h("div", { class: ix('bp-sdk-no-results', {
          'bp-sdk-visually-hidden': !this._showChoices,
        }) }, h("span", null, "No Results")));
    }
  }
  renderReadOnlyElement(value) {
    return h("span", { class: "read-only-value" }, value);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "labelId": ["onAriaLabelledByChange"],
    "labelledBy": ["onLabelledByChange"],
    "choices": ["onChoicesChange"],
    "choiceId": ["onChoiceIdChange"],
    "showChoices": ["onShowChoicesChange"],
    "choice": ["onChoiceChange"],
    "choiceText": ["onChoiceTextChange"],
    "value": ["onValueChange"],
    "filterText": ["onFilterChange"]
  }; }
};
BpSdkAutocompleteInput.style = bpSdkAutocompleteInputCss;

const bpSdkBusinessClassificationSelectorCardBodyCss = "";

let BpSdkBusinessClassificationSelectorCardBody = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-card-body');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-card-body').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-business-classification-selector-card-body", { explanation: this.explanation });
  }
  renderInternal() {
    return (h("div", { class: "'bp-sdk-business-classification-selector-card-body__container'" }, h("div", { class: "bp-sdk-business-classification-selector-card-body__text", innerHTML: this.explanation || '' })));
  }
};
BpSdkBusinessClassificationSelectorCardBody.style = bpSdkBusinessClassificationSelectorCardBodyCss;

const bpSdkBusinessClassificationSelectorCardContentCss = "";

let BpSdkBusinessClassificationSelectorCardContent = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Should show explanation
     */
    this.showExplanation = true;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-card-content');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-card-content').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-card-content", { alias: this.alias, value: this.value, highlights: this.highlights, confidence: this.confidence, explanation: this.explanation, showExplanation: this.showExplanation, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, showDetailedRelevanceChip: this.showDetailedRelevanceChip, isSelected: this.isSelected, isBestMatch: this.isBestMatch }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-card-content__container" }, h("bp-sdk-business-classification-selector-card-header", { alias: this.alias, confidence: this.confidence, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, value: this.value, highlights: this.highlights }), h("bp-sdk-business-classification-selector-card-body", { explanation: this.explanation }), this.showDetailedRelevanceChip && h("bp-sdk-business-classification-selector-relevance-chip", { confidence: this.confidence })));
  }
};
BpSdkBusinessClassificationSelectorCardContent.style = bpSdkBusinessClassificationSelectorCardContentCss;

const bpSdkBusinessClassificationSelectorCardHeaderCss = "";

let BpSdkBusinessClassificationSelectorCardHeader = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * List of highlight filters
     */
    this.highlightFilters = ['synonyms', 'value'];
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-card-header');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-card-header').then(() => {
      this.useExternal = true;
    });
    this.onHightLightsChange(this.highlights);
    this.onHighlightFilterChanges(this.highlightFilters);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  onHightLightsChange(highlights) {
    this.updateHighlight(this.highlightFilters, highlights);
  }
  onHighlightFilterChanges(filters) {
    this.updateHighlight(filters, this.highlights);
  }
  updateHighlight(filters, highlights = []) {
    const valueHighlight = Array.isArray(highlights) && (highlights === null || highlights === void 0 ? void 0 : highlights.find(({ field }) => filters.includes(field)));
    this.highlight = !!valueHighlight ? valueHighlight.text : this.value;
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-card-header", { alias: this.alias, confidence: this.confidence, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, value: this.value, highlights: this.highlights, highlightFilters: this.highlightFilters }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-card-header__container" }, h("span", { class: "bp-sdk-business-classification-selector-card-header__text" }, this.highlight && (h("span", { class: "bp-sdk-business-classification-selector-card-header__highlight", innerHTML: this.highlight })), this.showNaicsCode && h("span", { class: "bp-sdk-business-classification-selector-card-header__alias" }, " - ", this.alias)), this.showConfidence && h("bp-sdk-class-selector-relevance-chip", { confidence: this.confidence })));
  }
  static get watchers() { return {
    "highlights": ["onHightLightsChange"],
    "highlightFilters": ["onHighlightFilterChanges"]
  }; }
};
BpSdkBusinessClassificationSelectorCardHeader.style = bpSdkBusinessClassificationSelectorCardHeaderCss;

const bpSdkBusinessClassificationSelectorListCss = "";

let BpSdkBusinessClassificationSelectorList = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /***
     * Choices to display
     */
    this.choices = [];
    this.useExternal = false;
    this.groupedChoices = [];
    this.calculateGroupedChoices = (choices = []) => {
      var _a, _b;
      const topChoices = [...choices]
        .sort((a, b) => (b.score || 0) - (a.score || 0))
        .slice(0, ((_a = this.groupedChoicesConfig) === null || _a === void 0 ? void 0 : _a.maxResults) || 7);
      this.groupedChoices = a3(topChoices);
      this.highestChoiceScore = ((_b = this.groupedChoices[0]) === null || _b === void 0 ? void 0 : _b.score) || 1000;
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-list');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-list').then(() => {
      this.useExternal = true;
    });
    this.calculateGroupedChoices(this.choices);
  }
  onChoicesChange(choices) {
    this.calculateGroupedChoices(choices);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-list", { choices: this.choices, choiceId: this.choiceId, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, groupedChoicesConfig: this.groupedChoicesConfig }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-list__container" }, this.groupedChoices.map((choiceGroup) => {
      var _a, _b;
      return (h("bp-sdk-business-classification-selector-naics-group", { showNaicsCode: this.showNaicsCode, showConfidence: this.showConfidence, naicsCode: choiceGroup.alias, naicsExplanation: ((_a = choiceGroup.choices[0]) === null || _a === void 0 ? void 0 : _a.explanation) || '', naicsDescription: ((_b = choiceGroup.choices[0]) === null || _b === void 0 ? void 0 : _b.national_industry_description) || '', choices: choiceGroup.choices, choiceId: this.choiceId, highestChoiceScore: this.highestChoiceScore }));
    })));
  }
  static get watchers() { return {
    "choices": ["onChoicesChange"]
  }; }
};
BpSdkBusinessClassificationSelectorList.style = bpSdkBusinessClassificationSelectorListCss;

const bpSdkBusinessClassificationSelectorListContainerCss = "";

let BpSdkBusinessClassificationSelectorListContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /***
     * Choices to display
     */
    this.choices = [];
    /**
     * Grouped choices config
     */
    this.groupedChoicesConfig = { maxResults: 7 };
    this.useExternal = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        groupedChoicesConfig: { maxResults: getConfigOptions(state).bcsChoiceLimit },
      };
    };
  }
  resetState() {
    this.groupedChoicesConfig = { maxResults: 7 };
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-list-container');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-list-container').then(() => {
      this.useExternal = true;
    });
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-list-container", { choices: this.choices, choiceId: this.choiceId, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, groupedChoicesConfig: this.groupedChoicesConfig }));
  }
  renderInternal() {
    return (h("bp-sdk-business-classification-selector-list", { choices: this.choices, choiceId: this.choiceId, showConfidence: this.showConfidence, showNaicsCode: this.showNaicsCode, groupedChoicesConfig: this.groupedChoicesConfig }));
  }
  get el() { return getElement(this); }
};
BpSdkBusinessClassificationSelectorListContainer.style = bpSdkBusinessClassificationSelectorListContainerCss;

const bpSdkBusinessClassificationSelectorListItemCss = "";

let BpSdkBusinessClassificationSelectorListItem = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueUpdate = createEvent(this, "valueUpdate", 7);
    /**
     * Is choice selected
     */
    this.isSelected = false;
    /**
     * Should show explanation
     */
    this.showExplanation = true;
    this.useExternal = false;
    this.isExpanded = false;
    this.onSelection = (e) => {
      e.preventDefault();
      if (!this.locked) {
        this.valueUpdate.emit([this.choiceId]);
      }
    };
    this.onKeyPress = (e) => {
      if (e.key === 'Enter' || e.key === ' ') {
        this.onSelection(e);
      }
    };
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-list-item');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-list-item').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-list-item", { alias: this.alias, isSelected: this.isSelected, showExplanation: this.showExplanation, confidence: this.confidence, choiceId: this.choiceId, showConfidence: this.showConfidence, value: this.value, highlights: this.highlights, showDetailedRelevanceChip: this.showDetailedRelevanceChip, isBestMatch: this.isBestMatch, locked: this.locked }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-list-item__container" }, h("bp-sdk-business-classification-selector-card-content", { alias: this.alias, confidence: this.confidence, onClick: this.onSelection, showConfidence: this.showConfidence, showDetailedRelevanceChip: this.showDetailedRelevanceChip, value: this.value, highlights: this.highlights, isSelected: this.isSelected, isBestMatch: this.isBestMatch, tabIndex: 0, role: "button", onKeyPress: this.onKeyPress })));
  }
};
BpSdkBusinessClassificationSelectorListItem.style = bpSdkBusinessClassificationSelectorListItemCss;

const bpSdkBusinessClassificationSelectorListItemContainerCss = "";

let BpSdkBusinessClassificationSelectorListItemContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Is choice selected
     */
    this.isSelected = false;
    /**
     * Should show explanation
     */
    this.showExplanation = true;
    /**
     * Decision to show detailed relevance chip injected by redux
     */
    this.showDetailedRelevanceChip = false;
    this.useExternal = false;
    this.isLocked = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        showDetailedRelevanceChip: areDetailedRelevanceChipsEnabled(state),
        enableUserApplicationGuard: !!state.config.options.enableUserApplicationGuard,
        locked: state.application.form.locked,
        isOwner: doesUserOwnApplicationForm(state),
        hasPermissionToEdit: userHasPermission(state, {
          permission: v.ApplicationForms,
          action: h$1.Update,
        }),
      };
    };
  }
  onEnableUserApplicationGuard(enableUserApplicationGuard) {
    this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, enableUserApplicationGuard);
  }
  onHasPermissionToEdit(hasPermission) {
    this.updateIsLocked(this.locked, this.isOwner, hasPermission, this.enableUserApplicationGuard);
  }
  onIsOwner(isOwner) {
    this.updateIsLocked(this.locked, isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  onLocked(locked) {
    this.updateIsLocked(locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  updateIsLocked(locked, isOwner, hasPermission, enableUserApplicationGuard) {
    this.isLocked = locked || (enableUserApplicationGuard && (!isOwner || !hasPermission));
  }
  resetState() {
    this.showDetailedRelevanceChip = false;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-list-item-container');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-list-item-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-list-item-container", { alias: this.alias, choiceId: this.choiceId, confidence: this.confidence, isSelected: this.isSelected, showConfidence: this.showConfidence, showExplanation: this.showExplanation, value: this.value, highlights: this.highlights, showDetailedRelevanceChip: this.showDetailedRelevanceChip, isBestMatch: this.isBestMatch, locked: this.locked, isOwner: this.isOwner, hasPermissionToEdit: this.hasPermissionToEdit, enableUserApplicationGuard: this.enableUserApplicationGuard }));
  }
  renderInternal() {
    return (h("bp-sdk-business-classification-selector-list-item", { alias: this.alias, choiceId: this.choiceId, confidence: this.confidence, isSelected: this.isSelected, showConfidence: this.showConfidence, showExplanation: this.showExplanation, value: this.value, highlights: this.highlights, showDetailedRelevanceChip: this.showDetailedRelevanceChip, locked: this.isLocked, isBestMatch: this.isBestMatch }));
  }
  static get watchers() { return {
    "enableUserApplicationGuard": ["onEnableUserApplicationGuard"],
    "hasPermissionToEdit": ["onHasPermissionToEdit"],
    "isOwner": ["onIsOwner"],
    "locked": ["onLocked"]
  }; }
};
BpSdkBusinessClassificationSelectorListItemContainer.style = bpSdkBusinessClassificationSelectorListItemContainerCss;

const bpSdkBusinessClassificationSelectorNaicsGroupCss = "";

let BpSdkBusinessClassificationSelectorNaicsGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /***
     * Choices to display
     */
    this.choices = [];
    /**
     * NAICS code for this group
     */
    this.naicsCode = '';
    /**
     * NAICS explanation for this group
     */
    this.naicsExplanation = '';
    /**
     * NAICS industry description for this group
     */
    this.naicsDescription = '';
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-naics-group');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-naics-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-naics-group", { choices: this.choices, showConfidence: this.showNaicsCode, showNaicsCode: this.showNaicsCode, naicsCode: this.naicsCode, naicsDescription: this.naicsDescription, naicsExplanation: this.naicsExplanation, highestChoiceScore: this.highestChoiceScore, choiceId: this.choiceId }));
  }
  renderInternal() {
    var _a;
    return (h("div", { class: "bp-sdk-business-classification-selector-naics-group__container" }, h("bp-sdk-business-classification-selector-naics-group-header", { naicsCode: this.showNaicsCode ? this.naicsCode : undefined, naicsDescription: this.naicsDescription, naicsExplanation: this.naicsExplanation }), (_a = this.choices) === null || _a === void 0 ? void 0 :
      _a.map((choice) => (h("bp-sdk-business-classification-selector-list-item-container", { alias: choice.alias, choiceId: choice.id, confidence: choice.confidence, isSelected: choice.id === this.choiceId, showConfidence: this.showConfidence, showExplanation: choice.showExplanation, value: choice.value, highlights: choice.highlights, isBestMatch: choice.score === this.highestChoiceScore })))));
  }
};
BpSdkBusinessClassificationSelectorNaicsGroup.style = bpSdkBusinessClassificationSelectorNaicsGroupCss;

const bpSdkBusinessClassificationSelectorNaicsGroupHeaderCss = ".bp-sdk-business-classification-selector-naics-group-header__heading--popover{display:none}";

let BpSdkBusinessClassificationSelectorNaicsGroupHeader = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * NAICS description for this group
     */
    this.naicsDescription = '';
    /**
     * NAICS explanation for this group
     * This is hidden from displaying by default via CSS. The intention is to show it in a hover or popover
     */
    this.naicsExplanation = '';
    this.useExternal = false;
  }
  resetState() { }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-naics-group-header');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-naics-group-header').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-naics-group-header", { naicsCode: this.naicsCode, naicsExplanation: this.naicsExplanation, naicsDescription: this.naicsDescription }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-naics-group-header__container" }, h("h2", { class: "bp-sdk-business-classification-selector-naics-group-header__heading" }, this.naicsDescription, this.naicsCode && (h("span", { class: "bp-sdk-business-classification-selector-naics-group-header__heading--code" }, " - ", this.naicsCode)), this.naicsExplanation && (h("span", { class: "bp-sdk-business-classification-selector-naics-group-header__heading--popover" }, this.naicsExplanation)))));
  }
};
BpSdkBusinessClassificationSelectorNaicsGroupHeader.style = bpSdkBusinessClassificationSelectorNaicsGroupHeaderCss;

const bpSdkBusinessClassificationSelectorNudgeCss = "";

let BpSdkBusinessClassificationSelectorNudge = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
    this.onYesClick = (evt) => {
      var _a;
      this.handleYesClick((_a = this.refilter) === null || _a === void 0 ? void 0 : _a.key, evt);
    };
    this.onNoClick = (evt) => {
      var _a;
      this.handleNoClick((_a = this.refilter) === null || _a === void 0 ? void 0 : _a.key, evt);
    };
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-nudge');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-nudge').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-nudge", { refilter: this.refilter, handleYesClick: this.handleYesClick, handleNoClick: this.handleNoClick }));
  }
  renderInternal() {
    var _a;
    return (h("div", { class: "bp-sdk-business-classification-selector-nudge__container" }, h("span", { class: "bp-sdk-business-classification-selector-nudge__question" }, (_a = this.refilter) === null || _a === void 0 ? void 0 : _a.text), h("button", { class: "bp-sdk-business-classification-selector-nudge__btn bp-sdk-business-classification-selector-nudge__btn--yes", onClick: this.onYesClick }, "Yes"), h("button", { class: "bp-sdk-business-classification-selector-nudge__btn bp-sdk-business-classification-selector-nudge__btn--no", onClick: this.onNoClick }, "No")));
  }
};
BpSdkBusinessClassificationSelectorNudge.style = bpSdkBusinessClassificationSelectorNudgeCss;

const bpSdkBusinessClassificationSelectorNudgeContainerCss = "";

let BpSdkBusinessClassificationSelectorNudgeContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.nudgeAnswer = createEvent(this, "nudgeAnswer", 7);
    /**
     * Nudges available in the Redux store
     */
    this.nudges = [];
    this.useExternal = false;
    /**
     * Are nudges hidden from UI?
     */
    this.isHidden = true;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        nudges: getUnansweredRefiltersByQuestionId(state, this.questionId),
      };
    };
    this.handleYesClick = (key, evt) => {
      if (evt && !this.useExternal) {
        evt.stopPropagation();
      }
      this.nudgeAnswer.emit({
        key,
        answer: true,
      });
    };
    this.handleNoClick = (key, evt) => {
      if (evt && !this.useExternal) {
        evt.stopPropagation();
      }
      this.nudgeAnswer.emit({
        key,
        answer: false,
      });
    };
  }
  resetState() {
    this.isHidden = true;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-nudge-container');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-nudge-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-business-classification-selector-nudge-container", { isHidden: this.isHidden, nudges: this.nudges, questionId: this.questionId }));
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-business-classification-selector-nudge-container__container" }, this.nudges.map((refilter) => (h("bp-sdk-business-classification-selector-nudge", { refilter: refilter, handleYesClick: this.handleYesClick, handleNoClick: this.handleNoClick })))));
  }
};
BpSdkBusinessClassificationSelectorNudgeContainer.style = bpSdkBusinessClassificationSelectorNudgeContainerCss;

const bpSdkBusinessClassificationSelectorRelevanceChipCss = "";

let BpSdkBusinessClassificationSelectorRelevanceChip = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
    this.relevance = 'high';
  }
  onConfidenceChange(confidence) {
    let relevance = 'High';
    if (confidence === 1) {
      relevance = 'Medium';
    }
    else if (confidence <= 0) {
      relevance = 'Low';
    }
    this.relevance = relevance;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-business-classification-selector-relevance-chip');
    customElements.whenDefined('bp-sdk-external-business-classification-selector-relevance-chip').then(() => {
      this.useExternal = true;
    });
    this.onConfidenceChange(this.confidence);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-business-classification-selector-relevance-chip", { confidence: this.confidence });
  }
  renderInternal() {
    return (h("span", { class: "bp-sdk-business-classification-selector-relevance-chip__container" }, h("span", { class: "bp-sdk-business-classification-selector-relevance-chip__wrapper" }, h("span", { class: "bp-sdk-business-classification-selector-relevance-chip__content" }, this.relevance, " Relevance"))));
  }
  static get watchers() { return {
    "confidence": ["onConfidenceChange"]
  }; }
};
BpSdkBusinessClassificationSelectorRelevanceChip.style = bpSdkBusinessClassificationSelectorRelevanceChipCss;

const bpSdkDeleteButtonCss = "";

let BpSdkDeleteButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-delete-button');
    customElements.whenDefined('bp-sdk-external-delete-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-delete-button", null);
  }
  renderInternal() {
    return (h("button", { class: "bp-sdk-delete-button" }, h("bp-sdk-icon-container", { name: "trashcan" }, h("slot", null, "Delete"))));
  }
};
BpSdkDeleteButton.style = bpSdkDeleteButtonCss;

const bpSdkDialogCloseButtonCss = "";

let BpSdkDialogCloseButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-dialog-close-button');
    customElements.whenDefined('bp-sdk-external-dialog-close-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-dialog-close-button", null);
  }
  renderInternal() {
    return (h("bp-sdk-button", null, h("bp-sdk-icon-container", { name: "times" })));
  }
};
BpSdkDialogCloseButton.style = bpSdkDialogCloseButtonCss;

const bpSdkErrorsContainerCss = "";

let BpSdkErrorsContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * Error messages function map
     */
    this.errorMessages = BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES;
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-errors-container');
    customElements.whenDefined('bp-sdk-external-errors-container').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-errors-container", { answerId: this.answerId, errorText: this.errorText, errorMessages: this.errorMessages, errors: this.errors, fieldType: this.fieldType, maxDate: this.maxDate, max: this.max, minDate: this.minDate, min: this.min, pattern: this.pattern, questionId: this.questionId }));
  }
  renderInternal() {
    return (h("bp-sdk-errors", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, min: this.min, max: this.max, minDate: this.minDate, maxDate: this.maxDate, pattern: this.pattern, errorMessages: this.errorMessages, errors: this.errors, errorText: this.errorText }));
  }
};
BpSdkErrorsContainer.DEFAULT_ERROR_MESSAGES = {
  value: (min, max) => {
    if (min != null && max != null) {
      return `Please select a value in range of ${min} to ${max}.`;
    }
    else if (min != null) {
      return `Please select a value of ${min} or larger.`;
    }
    else {
      return `Please select a value of ${min} or smaller.`;
    }
  },
  length: (min, max) => {
    if (min != null && min === max) {
      return `Please rephrase your answer in ${min} characters.`;
    }
    else if (min != null && max != null) {
      return `Please rephrase your answer in ${min}-${max} characters.`;
    }
    else if (min != null) {
      return `Please rephrase your answer in more than ${min} characters.`;
    }
    else {
      return `Please rephrase your answer in less than ${max} characters.`;
    }
  },
  date: (min, max) => {
    if (min != null && max != null) {
      const range = min === max ? `of ${min}` : `between ${min} and ${max}`;
      return `Please select a date ${range}.`;
    }
    else if (min != null) {
      return `Please select a date after ${min}.`;
    }
    else {
      return `Please select a date before ${max}.`;
    }
  },
  required: () => 'An answer is required for this question.',
  pattern: () => 'Input does not look correct',
};
BpSdkErrorsContainer.style = bpSdkErrorsContainerCss;

const bpSdkIconContainerCss = "";

let BpSdkIconContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Additional css classes
     */
    this.cssClasses = '';
    this.useExternal = false;
    this.iconDefined = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-icon-container');
    customElements.whenDefined('bp-sdk-external-icon-container').then(() => {
      this.useExternal = true;
    });
    this.iconDefined = !!customElements.get('bp-sdk-icon');
    customElements.whenDefined('bp-sdk-external-icon').then(() => {
      this.iconDefined = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-icon-container", { name: this.name, cssClasses: this.cssClasses });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-icon__container" }, this.iconDefined && h("bp-sdk-icon", { name: this.name, cssClasses: this.cssClasses }), !this.iconDefined && h("span", { class: "bp-sdk-icon__container--fallback" }, this.name)));
  }
};
BpSdkIconContainer.style = bpSdkIconContainerCss;

const bpSdkMaskedInputButtonCss = "";

let BpSdkMaskedInputButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-masked-input-button');
    customElements.whenDefined('bp-sdk-external-masked-input-button').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-masked-input-button", { label: this.label });
  }
  renderInternal() {
    return (h("button", { "aria-label": this.label, class: "bp-sdk-masked-input-button__container" }, h("slot", null)));
  }
};
BpSdkMaskedInputButton.style = bpSdkMaskedInputButtonCss;

const bpSdkParentQuestionPoolSelectorCss = "bp-sdk-parent-question-pool-selector .bp-sdk-parent-question-pool-selector__container{position:relative;min-width:10 rem;max-width:100vw}.bp-sdk-hidden{position:fixed;top:-100rem}.bp-sdk-align-right{margin-left:auto}.bp-sdk-select__button-arrow{font-size:20px}.bp-sdk-select__list{background:white;border:1px solid #aaa;left:0;overflow-y:auto;margin:0;max-height:15rem;padding-left:0;position:absolute;width:100%;z-index:1}.bp-sdk-select__button{width:100%;height:2.5rem;background-color:white;display:flex;padding:0.5rem;justify-items:center;align-items:center;cursor:pointer}.bp-sdk-select__list-item{display:block;position:relative;font-size:16px;padding-left:1rem;padding-right:1rem;cursor:pointer}";

let BpSdkParentQuestionPoolSelector = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.selectedAnswerPoolId = createEvent(this, "selectedAnswerPoolId", 7);
    this.choices = [];
    this.useExternal = false;
    this.selectedChoiceId = '';
    this.selectValueUpdate = (ev) => {
      ev.stopPropagation();
      this.selectedChoiceId = ev.detail[0];
    };
    this.handleSubmit = () => {
      if (this.selectedChoiceId) {
        this.selectedAnswerPoolId.emit(this.selectedChoiceId);
        this.selectedChoiceId = undefined;
      }
    };
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-parent-question-pool-selector');
    customElements.whenDefined('bp-sdk-external-parent-question-pool-selector').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-parent-question-pool-selector", { choices: this.choices, label: this.label });
  }
  renderInternal() {
    return (h("div", { class: "bp-sdk-parent-question-pool-selector__container" }, h("bp-sdk-select-input", { choices: this.choices, label: this.label, onValueUpdate: this.selectValueUpdate, choiceId: this.selectedChoiceId }), this.selectedChoiceId && this.renderSubmitButton()));
  }
  renderSubmitButton() {
    if (!!this.selectedChoiceId) {
      return (h("button", { type: "button", class: "bp-sdk-button bp-sdk-parent-pool-selector__submit-button", onClick: this.handleSubmit }, "Next"));
    }
  }
};
BpSdkParentQuestionPoolSelector.style = bpSdkParentQuestionPoolSelectorCss;

const bpSdkSelectInputCss = "bp-sdk-select-input .bp-sdk-select__container{position:relative;min-width:10rem;max-width:100vw}.bp-sdk-hidden{position:fixed;top:-100rem}.bp-sdk-no-selection{user-select:none}.bp-sdk-visually-hidden{display:none}.bp-sdk-align-right{margin-left:auto}.bp-sdk-select__button-arrow{font-size:20px}.bp-sdk-select__list{background:white;border:1px solid #aaa;left:0;overflow-y:auto;margin:0;max-height:15rem;padding-left:0;position:absolute;width:100%;z-index:1}.bp-sdk-select__button{width:100%;height:2.5rem;background-color:white;display:flex;padding:0.5rem;justify-items:center;align-items:center;cursor:pointer}.bp-sdk-select__list-item{display:block;position:relative;font-size:16px;padding-left:1rem;padding-right:1rem;cursor:pointer}";

const selectButtonIdPrefix = 'select-btn-';
const keyboardNavigation = {
  next: ['ArrowRight', 'ArrowDown'],
  previous: ['ArrowLeft', 'ArrowUp'],
  select: ['Enter', ' '],
};
let BpSdkSelectInput = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueUpdate = createEvent(this, "valueUpdate", 7);
    this.removeActiveAnswer = createEvent(this, "removeActiveAnswer", 7);
    this.updateActiveAnswer = createEvent(this, "updateActiveAnswer", 7);
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Use alias for choices
     */
    this.useAlias = false;
    /**
     * Choice ids selected. Used for multiple selection.
     */
    this.choiceIds = [];
    /**
     * Whether to allow multi-select.
     */
    this.multiple = false;
    /**
     * Choices to display
     */
    this.choices = [];
    /**
     * Is Touched
     */
    this.touched = false;
    /**
     * Is Pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    this.choice = [];
    this._value = [];
    this.showSelectList = false;
    this.selectText = '';
    this.focusedIndex = 0;
    this.selectButtonId = `${selectButtonIdPrefix}${fx(8)}`;
    this.accumulateFilter = true;
    this.currentFilterText = '';
    this.useExternal = false;
    this.onKeydown = (event) => {
      const key = event.key;
      const isTab = key === 'Tab';
      if ((key !== 'Shift' && key !== 'Meta' && key !== 'Alt' && key !== 'Control' && !isTab) || (isTab && this.showSelectList)) {
        event.preventDefault();
        this.handleKeyEvent(key);
      }
    };
    this.onChange = (event) => {
      event.preventDefault();
      this.updateTextDisplayed(event.target.value);
    };
    this.clickSelectItem = (choiceId) => {
      let ctrlValue = choiceId || this.choice;
      if (this.multiple) {
        ctrlValue = this.getControlValue(choiceId);
      }
      else {
        this.clickSelectButton();
      }
      this.removeActiveAnswer.emit();
      this.choice = this._value = Array.isArray(ctrlValue) ? ctrlValue : [ctrlValue];
      this.updateTextDisplayed(ctrlValue);
    };
    this.delayedClickSelectItem = debounce_1(this.clickSelectItem, 8);
    this.updateTextDisplayed = debounce_1((choiceValue) => {
      if (this.multiple && Array.isArray(choiceValue) && choiceValue.length > 0) {
        this.updateMultiSelectText(choiceValue);
      }
      else if (choiceValue && typeof choiceValue === 'string') {
        this.updateSingleSelectText(choiceValue);
      }
      else {
        this.selectText = this.placeholder || '';
      }
    }, 20);
    this.listenToTextFilter = debounce_1((newValue) => this.handleTextEntry(newValue), 500);
    this.onSubmitButtonClick = ($event) => this.selectFocus($event);
    this.onAutocomplete = (e) => {
      const value = e.target.value;
      const choice = this.choices.find((choice) => choice.value === value);
      this.delayedClickSelectItem(choice.id);
    };
    this.onListBlur = () => {
      this.showSelectList = false;
    };
    this.onChoiceClick = (choice) => (e) => {
      e.stopPropagation();
      e.preventDefault();
      this.delayedClickSelectItem(choice.id);
    };
  }
  onAriaLabelledByChange(labelId) {
    this.updateLabelledBy(labelId, this.labelledBy);
  }
  onLabelledByChange(labelledBy) {
    this.updateLabelledBy(this.labelId, labelledBy);
  }
  updateLabelledBy(aria, ids) {
    const prefix = ids ? `${ids} ` : '';
    this._labelledBy = `${prefix}${aria !== null && aria !== void 0 ? aria : ''}` || undefined;
  }
  onCodeChange(newValue) {
    this.selectButtonId = `${selectButtonIdPrefix}${newValue}`;
  }
  onChoiceIdChange(choice) {
    this.choice = [choice];
    this.updateTextDisplayed(choice);
  }
  onChoiceIdsChange(choiceIds, oldIds) {
    if (isEqual_1(choiceIds, oldIds)) {
      return;
    }
    this.choice = choiceIds;
    this.updateTextDisplayed(choiceIds);
  }
  onShowSelectListChange(showList) {
    if (showList) {
      this.el.dispatchEvent(new FocusEvent('focusin', { bubbles: true }));
      this.updateActiveAnswer.emit(this.answerId);
    }
    else {
      this.removeActiveAnswer.emit();
    }
  }
  resetState() {
    this.showSelectList = false;
    this.accumulateFilter = true;
    this.currentFilterText = '';
  }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-select-input');
    customElements.whenDefined('bp-sdk-external-select-input').then(() => {
      this.useExternal = true;
    });
    this.onChoiceIdChange(this.choiceId);
    this.onChoiceIdsChange(this.choiceIds, []);
    this.onAriaLabelledByChange(this.labelId);
    this.onLabelledByChange(this.labelledBy);
  }
  focusOption(index) {
    this.showSelectList = true;
    this.focusedIndex = this.getSelectableIndex(index);
    setTimeout(() => {
      const optionList = this.el.querySelector('.bp-sdk-select__list');
      const element = optionList.children[this.focusedIndex];
      element.focus();
    }, 0);
  }
  selectFocus(e) {
    e.stopPropagation();
    e.preventDefault();
    if (!this.showSelectList) {
      this.focusElement();
    }
    else {
      this.showSelectList = false;
    }
  }
  focusElement() {
    this.showSelectList = true;
    this.el.dispatchEvent(new FocusEvent('focusin'));
    let focusIndex = 0;
    if (!this.multiple && this.choice.length) {
      const choiceId = this.choice[0];
      focusIndex = this.choices.findIndex((choice) => choice.id === choiceId);
    }
    this.focusOption(focusIndex);
  }
  choiceText(choice) {
    return this.useAlias && choice.alias ? choice.alias : choice.value;
  }
  getControlValue(choiceId) {
    if (this.isChosen(choiceId)) {
      return this.choice.filter((id) => id !== choiceId);
    }
    else {
      return [...this.choice, choiceId];
    }
  }
  clickSelectButton() {
    this.showSelectList = false;
    const selectButton = this.el.querySelector('.bp-sdk-select__button');
    selectButton === null || selectButton === void 0 ? void 0 : selectButton.focus();
  }
  isChosen(choiceId) {
    return (this.choice || []).includes(choiceId);
  }
  handleKeyEvent(keyName) {
    const options = this.getKeyEventOptions(keyName);
    const indexToSelect = this.getIndexToSelect(keyName, options);
    this.mapKeyEventToAction(keyName, indexToSelect, options);
  }
  getKeyEventOptions(keyName) {
    const goToNext = keyboardNavigation.next.includes(keyName);
    const goToPrevious = keyboardNavigation.previous.includes(keyName);
    const addToFilter = !goToNext && !goToPrevious && !!keyName && keyName !== ' ';
    const isOpenOrSelectKey = keyboardNavigation.select.includes(keyName) || (keyName === 'Tab' && this.showSelectList);
    const openSelectList = isOpenOrSelectKey && !this.showSelectList;
    return {
      goToNext,
      goToPrevious,
      shouldMoveIndex: goToPrevious || goToNext,
      addToFilter,
      isOpenOrSelectKey,
      openSelectList,
    };
  }
  getIndexToSelect(keyName, { goToPrevious, shouldMoveIndex, isOpenOrSelectKey }) {
    let indexToSelect;
    if (isOpenOrSelectKey && this.showSelectList) {
      indexToSelect = this.focusedIndex;
    }
    else if (keyName === 'Escape') {
      this.showSelectList = false;
    }
    else if (shouldMoveIndex && !this.showSelectList) {
      indexToSelect = !this.choice ? 0 : this.focusedIndex + (goToPrevious ? -1 : 1);
    }
    return indexToSelect;
  }
  mapKeyEventToAction(keyName, indexToSelect, { openSelectList, shouldMoveIndex, goToPrevious, addToFilter, }) {
    if (openSelectList) {
      this.focusOption(this.focusedIndex);
    }
    else if (typeof indexToSelect === 'number') {
      this.selectOptionByIndex(indexToSelect);
    }
    else if (shouldMoveIndex && this.showSelectList) {
      this.focusOption(this.focusedIndex + (goToPrevious ? -1 : 1));
    }
    else if (addToFilter) {
      this.filterText(keyName);
    }
  }
  selectOptionByIndex(index) {
    const selectableIndex = this.getSelectableIndex(index);
    this.focusedIndex = selectableIndex;
    const choice = this.choices[this.focusedIndex];
    this.delayedClickSelectItem(choice.id);
  }
  updateMultiSelectText(choiceIds) {
    const selectedChoices = this.choices.filter((c) => choiceIds.findIndex((id) => id === c.id) > -1);
    if (selectedChoices.length > 0) {
      this.selectText = selectedChoices.map((c) => (this.useAlias ? c.alias : c.value)).join(', ');
    }
  }
  updateSingleSelectText(choiceValue) {
    const choice = this.choices.find((c) => c.id === choiceValue);
    if (choice) {
      this.selectText = this.useAlias ? choice.alias : choice.value;
    }
  }
  onValueChange(newValue, oldValue) {
    if (Fe(newValue, oldValue)) {
      this.valueUpdate.emit(newValue);
    }
  }
  filterText(newValue) {
    let result = newValue;
    if (!this.accumulateFilter) {
      this.accumulateFilter = true;
    }
    else {
      result = this.currentFilterText + newValue;
    }
    this.currentFilterText = result;
    this.listenToTextFilter(result);
  }
  handleTextEntry(text) {
    var _a;
    this.accumulateFilter = false;
    const indexToFocus = (_a = (text && this.choices.findIndex((choice) => this.choiceText(choice).toLowerCase().startsWith(text.toLowerCase())))) !== null && _a !== void 0 ? _a : -1;
    const choice = this.choices[indexToFocus];
    if (this.showSelectList) {
      this.focusOption(indexToFocus);
    }
    else if (choice) {
      this.delayedClickSelectItem(choice.id);
    }
  }
  getSelectableIndex(index) {
    const lastIndex = this.choices.length - 1;
    const selectableIndex = index <= 0 ? 0 : index > lastIndex ? lastIndex : index;
    return selectableIndex;
  }
  handleOutsideClick() {
    this.showSelectList = false;
  }
  renderSubmitButton() {
    return (h("button", { type: "button", class: ix('bp-sdk-select__button', {
        'bp-sdk-touched': this.touched,
        'bp-sdk-pristine': this.pristine,
      }), "aria-haspopup": "listbox", disabled: !this.choices.length, "aria-labelledby": this._labelledBy || '' + ' ' + this.selectButtonId, onClick: this.onSubmitButtonClick, id: this.selectButtonId, "aria-label": this.selectText || this.placeholder, "aria-describedby": ax(dx(this.errors)) || undefined }, this.selectText || this.placeholder, h("span", { class: "bp-sdk-align-right bp-sdk-select__button-arrow" }, "\u25BE")));
  }
  renderHiddenOptions() {
    return (h("select", { "aria-hidden": true, tabindex: "-1", class: "bp-sdk-hidden", autocomplete: this.autoComplete, multiple: this.multiple, onInput: this.onAutocomplete }, this.choices.map((choice) => (h("option", { onClick: this.onChoiceClick(choice), selected: this.isChosen(choice.id), value: choice.value }, choice.alias)))));
  }
  renderMultiSelectChoices(choice) {
    return (h("label", { htmlFor: `bp-sdk-select__list-${this.answerId}-item__input-${choice.id}`, id: `bp-sdk-select__list-${this.answerId}-item__label-${choice.id}`, class: "bp-sdk-select-list-item-label" }, h("span", { class: "bp-sdk-no-selection" }, this.choiceText(choice)), h("input", { id: `bp-sdk-select__list-${this.answerId}-item__input-${choice.id}`, class: `bp-sdk-select__list-item-content bp-sdk-select__list-item-input bp-sdk-select__list-item-content-${this.code} bp-sdk-select__list-item-input-${this.code}`, type: "checkbox", checked: this.isChosen(choice.id), placeholder: this.choiceText(choice) })));
  }
  renderSingleSelectChoices(choice) {
    return (h("span", { class: `bp-sdk-select__list-item-content bp-sdk-select__list-item-text bp-sdk-select__list-item-content-${this.code} bp-sdk-select__list-item-text-${choice.id}` }, this.choiceText(choice)));
  }
  renderChoice(choice) {
    return [this.multiple && this.renderMultiSelectChoices(choice), !this.multiple && this.renderSingleSelectChoices(choice)];
  }
  renderChoices() {
    return this.choices.map((choice, i) => (h("li", { onClick: this.onChoiceClick(choice), "aria-labelledby": this.labelId, class: ix(`bp-sdk-select__list-item bp-sdk-select__list-item-${choice.id}`, {
        'bp-sdk-select__list-item-selected': this.isChosen(choice.id),
      }), role: "option", "aria-selected": (this.focusedIndex === i).toString(), tabindex: "1" }, this.renderChoice(choice))));
  }
  renderVisibleOptions() {
    return (h("ul", { class: ix('bp-sdk-select__list', {
        'bp-sdk-visually-hidden': !this.showSelectList,
      }), "aria-expanded": this.showSelectList, role: "listbox", "aria-labelledby": this.labelId, tabindex: "-1", onBlur: this.onListBlur }, this.renderChoices()));
  }
  renderOptions() {
    return [this.renderHiddenOptions(), this.renderVisibleOptions()];
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-select-input", { answerId: this.answerId, autoComplete: this.autoComplete, choiceId: this.choiceId, choiceIds: this.choiceIds, choices: this.choices, code: this.code, errorText: this.errorText, errors: this.errors, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, multiple: this.multiple, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, required: this.required, touched: this.touched, useAlias: this.useAlias, value: this.value }));
  }
  renderInternal() {
    var _a;
    let input;
    if (this.isReadOnly) {
      const selectedIds = [this.choiceId, ...(this.choiceIds || [])];
      const selectedChoices = (this.choices || [])
        .filter((choice) => selectedIds.includes(choice.id))
        .map((choice) => this.choiceText(choice))
        .join(', ');
      input = this.renderReadOnlyElement(selectedChoices);
    }
    else {
      input = [this.renderSubmitButton(), this.renderOptions()];
    }
    return (h("div", { class: "bp-sdk-select__container", onKeyDown: this.onKeydown }, h("label", { id: this.labelId, htmlFor: this.selectButtonId, class: "bp-sdk-label bp-sdk-select__label", innerHTML: this.label }), input, this.touched && !this.pristine && ((this.errorText && !this.isCompleted) || !!((_a = this.errors) === null || _a === void 0 ? void 0 : _a.length)) && (h("bp-sdk-errors-container", { answerId: this.answerId, questionId: this.questionId, fieldType: this.fieldType, errors: this.errors, errorText: this.errorText }))));
  }
  renderReadOnlyElement(value) {
    return h("span", { class: "read-only-value" }, value);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "labelId": ["onAriaLabelledByChange"],
    "labelledBy": ["onLabelledByChange"],
    "code": ["onCodeChange"],
    "choiceId": ["onChoiceIdChange"],
    "choiceIds": ["onChoiceIdsChange"],
    "showSelectList": ["onShowSelectListChange"],
    "_value": ["onValueChange"]
  }; }
};
BpSdkSelectInput.style = bpSdkSelectInputCss;

const bpSdkTextInputCss = "";

let BpSdkTextInput = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.valueUpdate = createEvent(this, "valueUpdate", 7);
    /**
     * Field type
     */
    this.fieldType = 'text';
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Is question required
     */
    this.required = false;
    /**
     * minimum length of input
     */
    this.min = -1;
    /**
     * maximum length of input
     */
    this.max = -1;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * is touched
     */
    this.touched = false;
    /**
     * is pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    /**
     * Is enabled
     */
    this.isEnabled = true;
    this._pattern = '';
    this._fieldType = 'text';
    this.useExternal = false;
    this.onChange = () => {
      const input = this.el.querySelector('.bp-sdk-text__input');
      this.valueUpdate.emit(input.value);
    };
  }
  updatePattern(fieldType, pattern) {
    if (fieldType === t.Number && !pattern) {
      pattern = '^\\d*';
    }
    else if (!pattern) {
      pattern = undefined;
    }
    this._pattern = pattern;
  }
  onAriaLabelledByChange(labelId) {
    this.updateLabelledBy(labelId, this.labelledBy);
  }
  onLabelledByChange(labelledBy) {
    this.updateLabelledBy(this.labelId, labelledBy);
  }
  updateLabelledBy(aria, ids) {
    const prefix = ids ? `${ids} ` : '';
    this._labelledBy = `${prefix}${aria !== null && aria !== void 0 ? aria : ''}` || undefined;
  }
  onFieldTypeChange(fieldType) {
    let type;
    if (fieldType === t.Number) {
      type = 'tel';
    }
    else {
      type = fieldType !== null && fieldType !== void 0 ? fieldType : 'text';
    }
    this._fieldType = type;
    this.updatePattern(fieldType, this.pattern);
  }
  onPatternChange(pattern) {
    this.updatePattern(this.fieldType, pattern);
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  handleExternalComponents() {
    this.useExternal = !!customElements.get('bp-sdk-external-text-input');
    customElements.whenDefined('bp-sdk-external-text-input').then(() => {
      this.useExternal = true;
    });
  }
  componentWillLoad() {
    this.handleExternalComponents();
    this.onFieldTypeChange(this.fieldType);
    this.onPatternChange(this.pattern);
    this.onAriaLabelledByChange(this.labelId);
    this.onLabelledByChange(this.labelledBy);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderTextInput() {
    var _a, _b;
    return (h("input", { "aria-describedby": ax(dx(this.errors)) || undefined, "aria-label": this.placeholder && !this.label ? this.placeholder : null, "aria-labelledby": this._labelledBy, autocomplete: this.autoComplete, class: "bp-sdk-text__input", disabled: !this.isEnabled, id: `bp-sdk-text-${this.labelId}__input-${this.answerId}`, maxLength: (_a = this.max) !== null && _a !== void 0 ? _a : -1, minLength: (_b = this.min) !== null && _b !== void 0 ? _b : -1, name: this.code, onChange: this.onChange, onInput: this.onChange, onPaste: this.onChange, pattern: this._pattern, placeholder: this.placeholder || '', required: this.required, type: this._fieldType, value: this.text }));
  }
  renderNumberInput() {
    var _a, _b;
    return (h("input", { "aria-describedby": ax(dx(this.errors)) || undefined, "aria-label": this.placeholder && !this.label ? this.placeholder : null, "aria-labelledby": this._labelledBy, autocomplete: this.autoComplete, class: "bp-sdk-text__input", disabled: !this.isEnabled, id: `bp-sdk-text-${this.labelId}__input-${this.answerId}`, max: (_a = this.max) !== null && _a !== void 0 ? _a : Number.MAX_VALUE, min: (_b = this.min) !== null && _b !== void 0 ? _b : Number.MIN_VALUE, name: this.code, onChange: this.onChange, onInput: this.onChange, onPaste: this.onChange, pattern: this._pattern, placeholder: this.placeholder || '', required: this.required, type: this._fieldType, value: this.text }));
  }
  renderInputElement() {
    return this.fieldType === t.Number ? this.renderNumberInput() : this.renderTextInput();
  }
  renderExternal() {
    return (h("bp-sdk-external-text-input", { answerId: this.answerId, autoComplete: this.autoComplete, code: this.code, errorText: this.errorText, errors: this.errors, fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isEnabled: this.isEnabled, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, max: this.max, min: this.min, pattern: this.pattern, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, readonly: this.isReadOnly, required: this.required, text: this.text, touched: this.touched }));
  }
  renderLabel() {
    return (this.label && (h("label", { id: this.labelId, htmlFor: `bp-sdk-text__${this.labelId}__input}-${this.answerId}`, class: "bp-sdk-label bp-sdk-text__label", innerHTML: this.label })));
  }
  renderErrors() {
    var _a;
    return (this.touched &&
      !this.pristine &&
      ((this.errorText && !this.isCompleted) || !!((_a = this.errors) === null || _a === void 0 ? void 0 : _a.length)) && (h("bp-sdk-errors-container", { questionId: this.questionId, fieldType: this.fieldType, pattern: this.pattern, min: this.min, max: this.max, errors: this.errors, errorText: this.errorText })));
  }
  renderInternal() {
    const element = this.isReadOnly ? this.renderReadOnlyElement(this.text) : this.renderInputElement();
    return (h("span", { class: "bp-sdk-text__container" }, this.renderLabel(), element, this.renderErrors()));
  }
  renderReadOnlyElement(value) {
    return h("span", { class: "read-only-value" }, value);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "labelId": ["onAriaLabelledByChange"],
    "labelledBy": ["onLabelledByChange"],
    "fieldType": ["onFieldTypeChange"],
    "pattern": ["onPatternChange"]
  }; }
};
BpSdkTextInput.style = bpSdkTextInputCss;

const bpSdkTextInputContainerCss = "";

let BpSdkTextInputContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * Field type
     */
    this.fieldType = 'text';
    /**
     * Placeholder to display
     */
    this.placeholder = '';
    /**
     * Is question required
     */
    this.required = false;
    /**
     * minimum length of input
     */
    this.min = -1;
    /**
     * maximum length of input
     */
    this.max = -1;
    /**
     * Error messages
     */
    this.errors = [];
    /**
     * is touched
     */
    this.touched = false;
    /**
     * is pristine
     */
    this.pristine = true;
    /**
     * Is answer in complete state
     */
    this.isCompleted = false;
    /**
     * When true, the field will be readonly. It will display only the label and value as plain text.
     */
    this.isReadOnly = false;
    /**
     * Is enabled
     */
    this.isEnabled = true;
    this.useExternal = false;
    this._vinErrors = [];
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        isAutocompleteEnabled: isAutocompleteEnabled(state),
      };
    };
  }
  resetState() {
    this._vinErrors = [];
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-text-input-container');
    customElements.whenDefined('bp-sdk-external-text-input-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
    this.onValueUpdate({
      detail: this.text,
    });
  }
  onValueUpdate(evt) {
    if (this.referenceType === u.CommercialAutoVIN) {
      if (VehicleVinService.isValidVin(evt.detail)) {
        this._vinErrors = [];
        this.errorText = undefined;
      }
      else {
        this.touched = true;
        this.pristine = false;
        this._vinErrors = [VehicleVinService.getValidationErrorMessage(evt.detail)];
        this.errorText = VehicleVinService.getValidationErrorMessage(evt.detail);
      }
    }
  }
  onReferenceTypeChange(referenceType) {
    this.updateAutocomplete({
      referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onCodeChange(code) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code,
      fieldType: this.fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onFieldTypeChange(fieldType) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType,
      isAutocompleteEnabled: this.isAutocompleteEnabled,
    });
  }
  onIsAutocompleteEnabledChange(isAutocompleteEnabled) {
    this.updateAutocomplete({
      referenceType: this.referenceType,
      code: this.code,
      fieldType: this.fieldType,
      isAutocompleteEnabled,
    });
  }
  updateAutocomplete({ code, fieldType, referenceType, isAutocompleteEnabled, }) {
    this.autoComplete = isAutocompleteEnabled ? f4({ referenceType, code, fieldType }) : undefined;
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-text-input-container", { answerId: this.answerId, code: this.code, errorText: this.errorText, errors: [...this._vinErrors, ...this.errors], fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isAutocompleteEnabled: this.isAutocompleteEnabled, isCompleted: this.isCompleted, isEnabled: this.isEnabled, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, max: this.max, min: this.min, pattern: this.pattern, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, referenceType: this.referenceType, required: this.required, text: this.text, touched: this.touched }));
  }
  renderInternal() {
    return [
      h("bp-sdk-text-input", { answerId: this.answerId, autoComplete: this.autoComplete, code: this.code, errorText: this.errorText, errors: [...this._vinErrors, ...this.errors], fieldType: this.fieldType, helpText: this.helpText, answeredBySource: this.answeredBySource, isCompleted: this.isCompleted, isEnabled: this.isEnabled, isReadOnly: this.isReadOnly, labelId: this.labelId, label: this.label, labelledBy: this.labelledBy, max: this.max, min: this.min, pattern: this.pattern, placeholder: this.placeholder, pristine: this.pristine, questionId: this.questionId, required: this.required, text: this.text, touched: this.touched }),
    ];
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "referenceType": ["onReferenceTypeChange"],
    "code": ["onCodeChange"],
    "fieldType": ["onFieldTypeChange"],
    "isAutocompleteEnabled": ["onIsAutocompleteEnabledChange"]
  }; }
};
BpSdkTextInputContainer.style = bpSdkTextInputContainerCss;

export { BpSdkAddItemContainer as bp_sdk_add_item_container, BpSdkAutocompleteInput as bp_sdk_autocomplete_input, BpSdkBusinessClassificationSelectorCardBody as bp_sdk_business_classification_selector_card_body, BpSdkBusinessClassificationSelectorCardContent as bp_sdk_business_classification_selector_card_content, BpSdkBusinessClassificationSelectorCardHeader as bp_sdk_business_classification_selector_card_header, BpSdkBusinessClassificationSelectorList as bp_sdk_business_classification_selector_list, BpSdkBusinessClassificationSelectorListContainer as bp_sdk_business_classification_selector_list_container, BpSdkBusinessClassificationSelectorListItem as bp_sdk_business_classification_selector_list_item, BpSdkBusinessClassificationSelectorListItemContainer as bp_sdk_business_classification_selector_list_item_container, BpSdkBusinessClassificationSelectorNaicsGroup as bp_sdk_business_classification_selector_naics_group, BpSdkBusinessClassificationSelectorNaicsGroupHeader as bp_sdk_business_classification_selector_naics_group_header, BpSdkBusinessClassificationSelectorNudge as bp_sdk_business_classification_selector_nudge, BpSdkBusinessClassificationSelectorNudgeContainer as bp_sdk_business_classification_selector_nudge_container, BpSdkBusinessClassificationSelectorRelevanceChip as bp_sdk_business_classification_selector_relevance_chip, BpSdkDeleteButton as bp_sdk_delete_button, BpSdkDialogCloseButton as bp_sdk_dialog_close_button, BpSdkErrorsContainer as bp_sdk_errors_container, BpSdkIconContainer as bp_sdk_icon_container, BpSdkMaskedInputButton as bp_sdk_masked_input_button, BpSdkParentQuestionPoolSelector as bp_sdk_parent_question_pool_selector, BpSdkSelectInput as bp_sdk_select_input, BpSdkTextInput as bp_sdk_text_input, BpSdkTextInputContainer as bp_sdk_text_input_container };
