import { r as registerInstance, c as createEvent, g as getElement } from './index-b4e0290f.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { isDebugMode } from '@boldpenguin/sdk-redux';
import { q as qe } from './index.esm.min-f8b70f0b.js';

const SDK_ERRORS = [new qe().name];
let BpSdkErrorEventContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.sdkError = createEvent(this, "sdkError", 7);
    /**
     * Debug flag injected from redux store
     */
    this.isDebug = false;
    this.handleError = (ev) => {
      try {
        const { error } = ev;
        if (SDK_ERRORS.includes(error === null || error === void 0 ? void 0 : error.name)) {
          // Emit DOM event
          this.sdkError.emit({ error });
          // Send error to console if debug flag is on
          this.isDebug && console.error(error);
          // Send to error handler function if it's provided
          this.errorHandler && this.errorHandler(error);
        }
      }
      catch (e) {
        // Swallow errors here, if we can't capture the error successfully just do nothing
      }
    };
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        isDebug: isDebugMode(state),
      };
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    window.addEventListener('error', this.handleError);
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  render() {
    return null;
  }
  get el() { return getElement(this); }
};

export { BpSdkErrorEventContainer as bp_sdk_error_event_container };
