import { r as registerInstance, h, c as createEvent, g as getElement } from './index-b4e0290f.js';
import { O } from './index.esm.min-f8b70f0b.js';
import { j as fx, y as bL, o as d9, Q as Q9 } from './index.esm.min-bfc5f0f4.js';
import { removeQuestionPool, getFormId, getPartnerEngineConfig } from '@boldpenguin/sdk-redux';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';

const bpSdkQuestionGroupCss = ".bp-sdk-row{display:flex;flex-direction:row}.bp-sdk-column{display:flex;flex-direction:column}.bp-sdk-space-between{justify-content:space-between}";

let BpSdkQuestionGroup = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * answers in group
     */
    this.answers = [];
    /**
     * Classes for styling group
     */
    this.classes = '';
    /**
     * Label id's for group
     */
    this.labelId = fx(8);
    this.useExternal = false;
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group');
    customElements.whenDefined('bp-sdk-external-question-group').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-question-group", { answers: this.answers, classes: this.classes, label: this.label, labelId: this.labelId, questionGroup: this.questionGroup, type: this.type }));
  }
  shouldRenderLabel() {
    // Adding a check to avoid accordion groups double rendering labels, this can likely be expanded to other group types but I don't have example data to test with
    return this.label && this.type !== O.Accordion;
  }
  renderInternal() {
    return [
      this.shouldRenderLabel() && h("bp-sdk-question-group-label", { labelId: this.labelId, label: this.label }),
      h("div", { class: this.classes }, this.renderContent()),
    ];
  }
  renderContent() {
    switch (this.type) {
      case O.Address:
        return h("bp-sdk-address-group", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case O.AccumulatePercentage:
        return h("bp-sdk-accumulation-question-group-container", { label: this.label, labelledBy: this.labelId, answers: this.answers });
      case O.Vehicle:
        return h("bp-sdk-vehicle-question-pool-container", { questionGroup: this.questionGroup });
      case O.Driver:
        return h("bp-sdk-driver-question-pool-container", { questionGroup: this.questionGroup });
      case O.Stepper:
        return h("bp-sdk-stepper-group-container", { questionGroup: this.questionGroup });
      case O.Accordion:
        return h("bp-sdk-accordion", { questionGroup: this.questionGroup });
      default:
        return this.answers.map((answer) => (h("bp-sdk-dynamic-input-redux-container", { answer: answer, shouldHideLabel: bL(this.label, answer), labelledBy: this.label ? this.labelId : '', id: `bp-sdk-question-group__${answer.question.id}`, class: "bp-sdk-question-group__question-set" })));
    }
  }
};
BpSdkQuestionGroup.style = bpSdkQuestionGroupCss;

const bpSdkQuestionGroupLabelCss = "";

let BpSdkQuestionGroupLabel = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.useExternal = false;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-group-label');
    customElements.whenDefined('bp-sdk-external-question-group-label').then(() => {
      this.useExternal = true;
    });
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return h("bp-sdk-external-question-group-label", { label: this.label, labelId: this.labelId });
  }
  renderInternal() {
    return (h("h2", { id: this.labelId, class: "bp-sdk-question-group__label" }, this.label));
  }
};
BpSdkQuestionGroupLabel.style = bpSdkQuestionGroupLabelCss;

const bpSdkVehicleQuestionPoolContainerCss = "";

let BpSdkVehicleQuestionPoolContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.deletePool = createEvent(this, "deletePool", 7);
    this.useExternal = false;
    this.isDeleting = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, { removeQuestionPool });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        applicationId: getFormId(state),
        config: getPartnerEngineConfig(state),
      };
    };
    this.handleDeleteItem = () => {
      this.isDeleting = true;
      this.removeQuestionPool({
        answer_pool_id: this.questionPoolId,
        application_id: this.applicationId,
        config: this.config,
        callback: () => {
          this.deletePool.emit(undefined);
        },
      });
      this.deletePool.emit(this.questionPoolId);
    };
  }
  resetState() { }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  disconnectedCallback() {
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onQuestionGroupChange(questionGroup) {
    this.questionPoolId = questionGroup === null || questionGroup === void 0 ? void 0 : questionGroup.poolId;
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-vehicle-question-pool-container');
    customElements.whenDefined('bp-sdk-external-vehicle-question-pool-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onQuestionGroupChange(this.questionGroup);
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h("bp-sdk-external-vehicle-question-pool-container", { applicationId: this.applicationId, config: this.config, questionGroup: this.questionGroup }));
  }
  renderInternal() {
    return (!this.isDeleting &&
      !!this.questionPoolId && (h("bp-sdk-vehicle-panel-container", { canDelete: true, isVehicleTrailer: d9(this.questionGroup), onDeleteItem: this.handleDeleteItem, questionGroup: this.questionGroup, answers: Q9(this.questionGroup), shouldShowTrailers: this.questionGroup.order >= 1 || d9(this.questionGroup) })));
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "questionGroup": ["onQuestionGroupChange"]
  }; }
};
BpSdkVehicleQuestionPoolContainer.style = bpSdkVehicleQuestionPoolContainerCss;

export { BpSdkQuestionGroup as bp_sdk_question_group, BpSdkQuestionGroupLabel as bp_sdk_question_group_label, BpSdkVehicleQuestionPoolContainer as bp_sdk_vehicle_question_pool_container };
