import { r as registerInstance, c as createEvent, h as h$1, F as Fragment, g as getElement } from './index-b4e0290f.js';
import { c as canGetStore, s as store } from './store-6dda1ad2.js';
import { saveQuestionSet, updateErrors, pushAnswer, removeActiveAnswerId, updateActiveAnswerId, checkAnswerQueue, getPartnerEngineConfig, doesUserOwnApplicationForm, userHasPermission, getAnswersState, getApplicationFormState, getQuestionPoolState, getQuestionSetState } from '@boldpenguin/sdk-redux';
import { v, h, o as oe, i, k } from './index.esm.min-f8b70f0b.js';
import { p as pc, v as va, g as gx, c as bl, $ as $L, n as na, e as v9, f as p9 } from './index.esm.min-bfc5f0f4.js';

let BpSdkQuestionSetContainer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.bpAnalyticsTrack = createEvent(this, "bpAnalyticsTrack", 7);
    /**
     * Question sets injected from redux
     */
    this.questionSets = {
      list: [],
      active: '',
      activeAnswerId: '',
      completedQuestionSetAnswerHasChanged: false,
      parentQuestionSets: [],
    };
    this.areResourcesReady = true;
    this.useExternal = false;
    this.canSave = true;
    this.isLocked = false;
    this.isReady = true;
    this.isFirstRun = true;
    this.isLoadingApplication = false;
    this.heartbeatInterval = undefined;
    this.isUpdating = false;
    this.handleSubscriptions = () => {
      if (canGetStore()) {
        this.storeUnsubscribe && this.storeUnsubscribe();
        store.mapDispatchToProps(this, {
          saveQuestionSet,
          updateErrors,
          pushAnswer,
          removeActiveAnswerId,
          updateActiveAnswerId,
          checkAnswerQueue,
        });
        this.storeUnsubscribe = store.mapStateToProps(this, this.mapStateToProps);
      }
    };
    this.mapStateToProps = (state) => {
      return {
        questionSets: state.application.questionSets,
        config: getPartnerEngineConfig(state),
        enableUserApplicationGuard: !!state.config.options.enableUserApplicationGuard,
        locked: state.application.form.locked,
        isOwner: doesUserOwnApplicationForm(state),
        hasPermissionToEdit: userHasPermission(state, {
          permission: v.ApplicationForms,
          action: h.Update,
        }),
        pendingProcesses: state.application.pendingProcesses,
        queue: state.queues.answers.queue,
        answersResourceState: getAnswersState(state),
        applicationFormResourceState: getApplicationFormState(state),
        questionPoolResourceState: getQuestionPoolState(state),
        questionSetResourceState: getQuestionSetState(state),
      };
    };
    this.handleSaveQuestionSet = (questionSet) => {
      const invalidAnswers = questionSet.answers.filter((answer) => !pc(answer));
      if (!invalidAnswers.length) {
        this.removeActiveAnswerId();
        this.saveQuestionSet({
          config: this.config,
          appFormQuestionSet: questionSet,
          navigationDirection: 'forward',
        });
        this.bpAnalyticsTrack.emit({
          eventName: oe.QuestionSetSaved,
          eventPayload: {
            applicationFormQuestionSetId: questionSet.id,
            questionSetId: questionSet.question_set_id,
            questionSetCode: questionSet.question_set.code,
          },
        });
      }
      else {
        invalidAnswers.forEach((answer) => {
          this.updateErrors({ answer, errors: va(answer) });
        });
        gx();
      }
    };
  }
  resetState() {
    this.isReady = true;
    this.isFirstRun = true;
    this.isLoadingApplication = false;
  }
  connectedCallback() {
    this.resetState();
    this.handleSubscriptions();
  }
  componentWillLoad() {
    this.useExternal = !!customElements.get('bp-sdk-external-question-set-container');
    customElements.whenDefined('bp-sdk-external-question-set-container').then(() => {
      this.useExternal = true;
    });
    this.handleSubscriptions();
    this.onAnswersResourcesStateChange(this.answersResourceState);
    this.onApplicationFormResourceStateChange(this.applicationFormResourceState);
    this.onHasPermissionToEdit(this.hasPermissionToEdit);
    this.onEnableUserApplicationGuard(this.enableUserApplicationGuard);
    this.onIsFirstRun(this.isFirstRun);
    this.onIsOwner(this.isOwner);
    this.onIsReady(this.isReady);
    this.onLocked(this.locked);
    this.onQuestionPoolResourcesStateChange(this.questionPoolResourceState);
    this.onQuestionSetResourcesStateChange(this.questionSetResourceState);
    this.onQueueChange(this.queue);
  }
  onQueueChange(queue, oldQueue) {
    this.canSave = !(queue === null || queue === void 0 ? void 0 : queue.length) && !this.doesCurrentQuestionSetHaveAPendingProcess();
    // While there is a queue, send a heartbeat to make sure redux is parsing it
    if ((queue === null || queue === void 0 ? void 0 : queue.length) && !(oldQueue === null || oldQueue === void 0 ? void 0 : oldQueue.length) && !this.heartbeatInterval) {
      this.heartbeatInterval = setInterval(() => {
        this.checkAnswerQueue();
      }, 250);
    }
    // If the queue has emptied, stop the heartbeat
    if (!(queue === null || queue === void 0 ? void 0 : queue.length) && (oldQueue === null || oldQueue === void 0 ? void 0 : oldQueue.length) && this.heartbeatInterval) {
      clearInterval(this.heartbeatInterval);
      this.heartbeatInterval = undefined;
    }
  }
  onEnableUserApplicationGuard(enableUserApplicationGuard) {
    this.updateIsLocked(this.locked, this.isOwner, this.hasPermissionToEdit, enableUserApplicationGuard);
  }
  onHasPermissionToEdit(hasPermission) {
    this.updateIsLocked(this.locked, this.isOwner, hasPermission, this.enableUserApplicationGuard);
  }
  onIsOwner(isOwner) {
    this.updateIsLocked(this.locked, isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  onLocked(locked) {
    this.updateIsLocked(locked, this.isOwner, this.hasPermissionToEdit, this.enableUserApplicationGuard);
  }
  onPendingProcessesChange(processes) {
    this.canSave = !this.doesCurrentQuestionSetHaveAPendingProcess(processes);
  }
  updateIsLocked(locked, isOwner, hasPermission, enableUserApplicationGuard) {
    this.isLocked = locked || (enableUserApplicationGuard && (!isOwner || !hasPermission));
  }
  onIsFirstRun(isFirstRun) {
    this.updateAreResourcesReady(isFirstRun, this.isReady);
  }
  onIsReady(isReady) {
    this.updateAreResourcesReady(this.isFirstRun, isReady);
  }
  updateAreResourcesReady(isFirstRun, isReady) {
    this.areResourcesReady = isFirstRun || isReady;
  }
  disconnectedCallback() {
    if (this.heartbeatInterval)
      clearInterval(this.heartbeatInterval);
    this.storeUnsubscribe && this.storeUnsubscribe();
  }
  onRemoveActiveAnswerRequest() {
    this.removeActiveAnswerId();
  }
  onUpdateActiveAnswerRequest({ detail }) {
    const answer = this.questionSets.list.reduce((acc, list) => acc || list.answers.find((answer) => answer.id === detail), null);
    if (answer) {
      this.updateActiveAnswerId(answer.id);
    }
  }
  onAnswersResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: state,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onApplicationFormResourceStateChange(state) {
    if (this.isFirstRun && state === i.Loaded) {
      this.isFirstRun = false;
    }
    if (state === i.Loading) {
      this.isLoadingApplication = true;
    }
    else {
      this.isLoadingApplication = false;
    }
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: state,
      questionPools: this.questionPoolResourceState,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionPoolResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: state,
      questionSets: this.questionSetResourceState,
    });
  }
  onQuestionSetResourcesStateChange(state) {
    this.isReady = this.calculateResourcesReady({
      answers: this.answersResourceState,
      applicationForm: this.applicationFormResourceState,
      questionPools: this.questionPoolResourceState,
      questionSets: state,
    });
  }
  calculateResourcesReady(resources = {}) {
    if (!resources ||
      resources.applicationForm !== i.Loaded ||
      resources.answers === i.Loading ||
      resources.questionPools === i.Loading ||
      resources.questionSets === i.Loading) {
      return false;
    }
    return true;
  }
  handleSaveAnswer(event) {
    if (this.useExternal) {
      return;
    }
    const { answer, new_value } = event.detail;
    const updatedAnswer = bl(answer, new_value);
    if ($L(answer, new_value) || (na(updatedAnswer) && !answer.is_completed)) {
      this.pushAnswer(updatedAnswer);
    }
  }
  componentWillUpdate() {
    this.handleSubscriptions();
  }
  render() {
    return [this.useExternal && this.renderExternal(), !this.useExternal && this.renderInternal()];
  }
  renderExternal() {
    return (h$1("bp-sdk-external-question-set-container", { answersResourceState: this.answersResourceState, applicationFormResourceState: this.applicationFormResourceState, config: this.config, enableUserApplicationGuard: this.enableUserApplicationGuard, hasPermissionToEdit: this.hasPermissionToEdit, isOwner: this.isOwner, locked: this.locked, pendingProcesses: this.pendingProcesses, questionPoolResourceState: this.questionPoolResourceState, questionSetResourceState: this.questionSetResourceState, questionSets: this.questionSets, queue: this.queue }));
  }
  renderQuestionSetHeader(set) {
    var _a, _b, _c, _d;
    return (h$1("bp-sdk-question-set-header", { applicationId: set.application_form_id, code: (_a = set.question_set) === null || _a === void 0 ? void 0 : _a.code, isActive: set.is_active, isCompleted: set.is_completed, name: (_b = set.question_set) === null || _b === void 0 ? void 0 : _b.name, setId: set.question_set_id, setTitle: (_c = set.question_set) === null || _c === void 0 ? void 0 : _c.title, tenantId: (_d = set.question_set) === null || _d === void 0 ? void 0 : _d.tenant_id }));
  }
  shouldRenderQuestionGroup(questionGroupsWithAnswersAsKey, answer) {
    return questionGroupsWithAnswersAsKey.has(answer.id);
  }
  renderQuestionSet(set) {
    var _a;
    // Gets multiple separate groups/nested groups
    const questionGroupsWithAnswersAsKey = v9(set, p9(set));
    if (set.is_blank) {
      return h$1("bp-sdk-question-set-empty", { questionSet: set.question_set });
    }
    switch ((_a = set.question_set) === null || _a === void 0 ? void 0 : _a.code) {
      // These two special cases are the legacy question groups CA components,
      // the question pools CA flow goes down into the question-set component
      case 'driver_master_question_set':
        return (h$1("bp-sdk-driver-question-set-container", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.isLocked, questionSet: set, saveHandler: this.handleSaveQuestionSet, questionGroupsWithAnswersAsKey: questionGroupsWithAnswersAsKey }));
      case 'vehicle_master_question_set':
        return (h$1("bp-sdk-vehicle-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.isLocked, questionSet: set, saveHandler: this.handleSaveQuestionSet, questionGroupsWithAnswersAsKey: questionGroupsWithAnswersAsKey }));
      default:
        return (h$1("bp-sdk-question-set", { areResourcesReady: this.areResourcesReady, canSave: this.canSave, locked: this.isLocked, questionSet: set, saveHandler: this.handleSaveQuestionSet, questionGroupsWithAnswersAsKey: questionGroupsWithAnswersAsKey, shouldRenderQuestionGroup: this.shouldRenderQuestionGroup }));
    }
  }
  renderPendingProcessesContainer() {
    return h$1("bp-sdk-pending-process-container", { pendingProcesses: this.pendingProcesses });
  }
  renderInternal() {
    if (!canGetStore()) {
      return null;
    }
    let activeQuestionSet = this.questionSets.list[this.questionSets.list.length - 1];
    if (this.isFirstRun && this.isLoadingApplication) {
      return h$1("bp-sdk-application-load", null);
    }
    if (this.questionSets.active && this.questionSets.active !== '') {
      activeQuestionSet = this.questionSets.list.find((qs) => qs.question_set_id === this.questionSets.active);
    }
    if (activeQuestionSet) {
      return (h$1(Fragment, null, this.renderQuestionSetHeader(activeQuestionSet), this.renderQuestionSet(activeQuestionSet), this.renderPendingProcessesContainer()));
    }
  }
  doesCurrentQuestionSetHaveAPendingProcess(processes) {
    const currentProcesses = processes ? processes : this.pendingProcesses;
    if (!(currentProcesses === null || currentProcesses === void 0 ? void 0 : currentProcesses.length)) {
      return false;
    }
    return currentProcesses.some((process) => process.state !== k.Completed && process.question_set_id === this.questionSets.active);
  }
  get el() { return getElement(this); }
  static get watchers() { return {
    "queue": ["onQueueChange"],
    "enableUserApplicationGuard": ["onEnableUserApplicationGuard"],
    "hasPermissionToEdit": ["onHasPermissionToEdit"],
    "isOwner": ["onIsOwner"],
    "locked": ["onLocked"],
    "pendingProcesses": ["onPendingProcessesChange"],
    "isFirstRun": ["onIsFirstRun"],
    "isReady": ["onIsReady"],
    "answersResourceState": ["onAnswersResourcesStateChange"],
    "applicationFormResourceState": ["onApplicationFormResourceStateChange"],
    "questionPoolResourceState": ["onQuestionPoolResourcesStateChange"],
    "questionSetResourceState": ["onQuestionSetResourcesStateChange"]
  }; }
};

export { BpSdkQuestionSetContainer as bp_sdk_question_set_container };
